feijoa.jobs package
===================

Submodules
----------

feijoa.jobs.job module
----------------------

.. automodule:: feijoa.jobs.job
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: feijoa.jobs
   :members:
   :undoc-members:
   :show-inheritance:
